#!/bin/bash

# ===========================================================================================================
# title         : install_spack_env.sh
# usage         : ./install_spack_env.sh $INSTALLATION_ROOT $SPACK_VERSION $EBRAINS_REPO $SPACK_ENV
# description   : installs or updates the spack environment defined in the EBRAINS spack repo
#                 (if the specified spack instance doesn't exist, it also creates it)
# ===========================================================================================================

INSTALLATION_ROOT=$1
SPACK_VERSION=$2
EBRAINS_REPO=$3
SPACK_ENV=$4

# specify location of .spack dir (by default in ~)
export SPACK_USER_CACHE_PATH=$INSTALLATION_ROOT/spack/.spack
export SPACK_USER_CONFIG_PATH=$INSTALLATION_ROOT/spack/.spack

# initial setup: if spack dir doesn't already exist, clone it and install gcc and python
if [ ! -d $INSTALLATION_ROOT/spack ]
then
  # clone spack repo, import packages.yaml config file and activate
  git clone --depth 1 -c advice.detachedHead=false -c feature.manyFiles=true --branch $SPACK_VERSION https://github.com/spack/spack $INSTALLATION_ROOT/spack
  cp $EBRAINS_REPO/packages.yaml $INSTALLATION_ROOT/spack/etc/spack/packages.yaml
  source $INSTALLATION_ROOT/spack/share/spack/setup-env.sh
  # install platform compiler and python (extract versions from packages.yaml)
  EBRAINS_SPACK_COMPILER=$(grep 'compiler' $EBRAINS_REPO/packages.yaml | awk -F'[][]' '{ print $2 }')
  EBRAINS_SPACK_PYTHON=python@$(grep -A1 'python' $EBRAINS_REPO/packages.yaml | tail -n1 | awk -F'[][]' '{ print $2 }')
  spack compiler find
  spack install $EBRAINS_SPACK_COMPILER
  spack load $EBRAINS_SPACK_COMPILER
  spack compiler find
  spack install $EBRAINS_SPACK_PYTHON %$EBRAINS_SPACK_COMPILER
else
  source $INSTALLATION_ROOT/spack/share/spack/setup-env.sh
fi

# add repo if it does not exist
if [[ ! $(spack repo list | grep $EBRAINS_REPO) ]]
then
  spack repo add $EBRAINS_REPO
fi

# create environment if it does not exist
if [ ! -d "$SPACK_ROOT/var/spack/environments/$SPACK_ENV" ]
then
  spack env create $SPACK_ENV
fi

# activate environment
cp $EBRAINS_REPO/spack.yaml $SPACK_ROOT/var/spack/environments/$SPACK_ENV/spack.yaml
spack env activate $SPACK_ENV
# remove any existing concrete specs from spack.lock and re-concretize everything
spack concretize --fresh --force
# install the environment, use 2 jobs to reduce the amount of required RAM
spack install --fresh --no-check-signature -y -j2

# create modules files with spack
spack module tcl refresh -y
# rebuild spack's database
spack reindex
# create loads script that when sourced activates and loads the installed spack environment
spack env loads -r
